@@ -1,5 +1,5 @@
 from django.contrib import admin
-from edc_model_admin import SimpleHistoryAdmin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from edc_adverse_event.modeladmin_mixins import (
     AeFollowupModelAdminMixin,
