@@ -1,6 +1,6 @@
 from django.db import models
 from edc_action_item.managers import (
-    ActionIdentifierManager,
+    ActionIdentifierModelManager,
     ActionIdentifierSiteManager,
 )
 from edc_action_item.models import ActionModelMixin
@@ -15,13 +15,13 @@ from .ae_tmg_methods_model_mixin import AeTmgMethodsModelMixin
 
 
 class AeTmgModelMixin(
-    NonUniqueSubjectIdentifierFieldMixin,
-    AeTmgFieldsModelMixin,
     AeTmgMethodsModelMixin,
-    ReportStatusModelMixin,
-    SearchSlugModelMixin,
     SiteModelMixin,
     ActionModelMixin,
+    NonUniqueSubjectIdentifierFieldMixin,
+    AeTmgFieldsModelMixin,
+    ReportStatusModelMixin,
+    SearchSlugModelMixin,
     models.Model,
 ):
 
@@ -29,7 +29,7 @@ class AeTmgModelMixin(
 
     on_site = ActionIdentifierSiteManager()
 
-    objects = ActionIdentifierManager()
+    objects = ActionIdentifierModelManager()
 
     class Meta:
         abstract = True
