@@ -28,8 +28,6 @@ class AeSusarModelAdminMixin(
         "subject_identifier",
         "action_identifier",
         "ae_initial__action_identifier",
-        "ae_initial__tracking_identifier",
-        "tracking_identifier",
     )
 
     fieldsets = (
